@@ -16,6 +16,7 @@
 #include <QDialog>
 
 #include <KConfigGroup>
+#include <KFileFilter>
 
 class KFileWidget;
 class QDialogButtonBox;
@@ -29,6 +30,7 @@ public:
 
     explicit FileDialog(QDialog *parent = nullptr, Qt::WindowFlags flags = {});
     ~FileDialog() override;
+    Q_DISABLE_COPY_MOVE(FileDialog)
 
 private:
     QDialogButtonBox *m_buttons;
@@ -71,7 +73,6 @@ public:
     typedef QList<Option> OptionList;
 
     explicit FileChooserPortal(QObject *parent);
-    ~FileChooserPortal() override;
 
 public Q_SLOTS:
     uint OpenFile(const QDBusObjectPath &handle,
@@ -95,14 +96,18 @@ private:
 
     static QString ExtractAcceptLabel(const QVariantMap &options);
 
-    static void ExtractFilters(const QVariantMap &options,
-                               QStringList &nameFilters,
-                               QStringList &mimeTypeFilters,
-                               QMap<QString, FilterList> &allFilters,
-                               QString &selectedMimeTypeFilter);
+    struct FilterExtract {
+        QVector<KFileFilter> filters;
+        KFileFilter currentFilter;
+    };
+
+    static FilterExtract ExtractFilters(const QVariantMap &options);
 
     static bool isMobile();
 
+    static FilterList fileFilterToFilterList(const KFileFilter &filter);
+    static KFileFilter filterListToFileFilter(const FilterList &list);
+
     MobileFileDialog *m_mobileFileDialog = nullptr;
 };
 
