@@ -110,11 +110,6 @@ void WaylandIntegration::acquireStreamingInput(bool acquire)
     globalWaylandIntegration->acquireStreamingInput(acquire);
 }
 
-WaylandIntegration::Stream WaylandIntegration::startStreamingOutput(quint32 outputName, Screencasting::CursorMode mode)
-{
-    return globalWaylandIntegration->startStreamingOutput(outputName, mode);
-}
-
 WaylandIntegration::Stream WaylandIntegration::startStreamingOutput(QScreen *screen, Screencasting::CursorMode mode)
 {
     return globalWaylandIntegration->startStreamingOutput(screen, mode);
@@ -125,6 +120,11 @@ WaylandIntegration::Stream WaylandIntegration::startStreamingWorkspace(Screencas
     return globalWaylandIntegration->startStreamingWorkspace(mode);
 }
 
+WaylandIntegration::Stream WaylandIntegration::startStreamingRegion(const QRect &region, Screencasting::CursorMode mode)
+{
+    return globalWaylandIntegration->startStreamingRegion(region, mode);
+}
+
 WaylandIntegration::Stream WaylandIntegration::startStreamingVirtual(const QString &name, const QSize &size, Screencasting::CursorMode mode)
 {
     return globalWaylandIntegration->startStreamingVirtualOutput(name, size, mode);
@@ -195,44 +195,11 @@ void WaylandIntegration::requestTouchUp(quint32 touchPoint)
     globalWaylandIntegration->requestTouchUp(touchPoint);
 }
 
-QMap<quint32, WaylandIntegration::WaylandOutput> WaylandIntegration::screens()
-{
-    return globalWaylandIntegration->screens();
-}
-
 void WaylandIntegration::setParentWindow(QWindow *window, const QString &parentWindow)
 {
     globalWaylandIntegration->setParentWindow(window, parentWindow);
 }
 
-// Thank you kscreen
-void WaylandIntegration::WaylandOutput::setOutputType(const QString &type)
-{
-    const auto embedded = {
-        QLatin1String("LVDS"),
-        QLatin1String("IDP"),
-        QLatin1String("EDP"),
-        QLatin1String("LCD"),
-    };
-
-    for (const QLatin1String &pre : embedded) {
-        if (type.startsWith(pre, Qt::CaseInsensitive)) {
-            m_outputType = OutputType::Laptop;
-            return;
-        }
-    }
-
-    if (type.contains(QLatin1String("VGA")) || type.contains(QLatin1String("DVI")) || type.contains(QLatin1String("HDMI"))
-        || type.contains(QLatin1String("Panel")) || type.contains(QLatin1String("DisplayPort")) || type.startsWith(QLatin1String("DP"))
-        || type.contains(QLatin1String("unknown"))) {
-        m_outputType = OutputType::Monitor;
-    } else if (type.contains(QLatin1String("TV"))) {
-        m_outputType = OutputType::Television;
-    } else {
-        m_outputType = OutputType::Monitor;
-    }
-}
-
 KWayland::Client::PlasmaWindowManagement *WaylandIntegration::plasmaWindowManagement()
 {
     return globalWaylandIntegration->plasmaWindowManagement();
@@ -284,24 +251,6 @@ WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startS
     return startStreaming(m_screencasting->createWindowStream(uuid, cursorMode), {{QLatin1String("source_type"), static_cast<uint>(ScreenCastPortal::Window)}});
 }
 
-WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startStreamingOutput(quint32 outputName, Screencasting::CursorMode mode)
-{
-    auto output = m_outputMap.value(outputName).output();
-    if (!output) {
-        qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "Cannot stream, output not found" << outputName << m_outputMap.keys();
-        auto notification = new KNotification(QStringLiteral("screencastfailure"), KNotification::CloseOnTimeout);
-        notification->setTitle(i18n("Failed to start screencasting"));
-        notification->setIconName(QStringLiteral("dialog-error"));
-        notification->sendEvent();
-        return {};
-    }
-    return startStreaming(m_screencasting->createOutputStream(output.data(), mode),
-                          {
-                              {QLatin1String("size"), output->geometry().size()},
-                              {QLatin1String("source_type"), static_cast<uint>(ScreenCastPortal::Monitor)},
-                          });
-}
-
 WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startStreamingOutput(QScreen *screen, Screencasting::CursorMode mode)
 {
     auto stream = m_screencasting->createOutputStream(screen, mode);
@@ -335,6 +284,15 @@ WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startS
                           });
 }
 
+WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startStreamingRegion(const QRect region, Screencasting::CursorMode mode)
+{
+    return startStreaming(m_screencasting->createRegionStream(region, 1, mode),
+                          {
+                              {QLatin1String("size"), region.size()},
+                              {QLatin1String("source_type"), static_cast<uint>(ScreenCastPortal::Monitor)},
+                          });
+}
+
 WaylandIntegration::Stream
 WaylandIntegration::WaylandIntegrationPrivate::startStreamingVirtualOutput(const QString &name, const QSize &size, Screencasting::CursorMode mode)
 {
@@ -626,11 +584,6 @@ void WaylandIntegration::WaylandIntegrationPrivate::requestTouchUp(quint32 touch
     }
 }
 
-QMap<quint32, WaylandIntegration::WaylandOutput> WaylandIntegration::WaylandIntegrationPrivate::screens()
-{
-    return m_outputMap;
-}
-
 static const char *windowParentHandlePropertyName = "waylandintegration-parentHandle";
 void WaylandIntegration::WaylandIntegrationPrivate::setParentWindow(QWindow *window, const QString &parentHandle)
 {
@@ -673,34 +626,6 @@ KWayland::Client::PlasmaWindowManagement *WaylandIntegration::WaylandIntegration
     return m_windowManagement;
 }
 
-void WaylandIntegration::WaylandIntegrationPrivate::addOutput(quint32 name, quint32 version)
-{
-    QSharedPointer<KWayland::Client::Output> output(new KWayland::Client::Output(this));
-    output->setup(m_registry->bindOutput(name, version));
-
-    connect(output.data(), &KWayland::Client::Output::changed, this, [this, name, version, output]() {
-        qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "Adding output:";
-        qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "    manufacturer: " << output->manufacturer();
-        qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "    model: " << output->model();
-        qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "    resolution: " << output->pixelSize();
-
-        WaylandOutput portalOutput;
-        portalOutput.setOutput(output);
-        portalOutput.setWaylandOutputName(name);
-        portalOutput.setWaylandOutputVersion(version);
-
-        m_outputMap.insert(name, portalOutput);
-    });
-}
-
-void WaylandIntegration::WaylandIntegrationPrivate::removeOutput(quint32 name)
-{
-    WaylandOutput output = m_outputMap.take(name);
-    qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "Removing output:";
-    qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "    manufacturer: " << output.manufacturer();
-    qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "    model: " << output.model();
-}
-
 void WaylandIntegration::WaylandIntegrationPrivate::initWayland()
 {
     auto connection = KWayland::Client::ConnectionThread::fromApplication(QGuiApplication::instance());
@@ -714,8 +639,6 @@ void WaylandIntegration::WaylandIntegrationPrivate::initWayland()
     connect(m_registry, &KWayland::Client::Registry::fakeInputAnnounced, this, [this](quint32 name, quint32 version) {
         m_fakeInput = m_registry->createFakeInput(name, version, this);
     });
-    connect(m_registry, &KWayland::Client::Registry::outputAnnounced, this, &WaylandIntegrationPrivate::addOutput);
-    connect(m_registry, &KWayland::Client::Registry::outputRemoved, this, &WaylandIntegrationPrivate::removeOutput);
 
     connect(m_registry, &KWayland::Client::Registry::interfaceAnnounced, this, [this](const QByteArray &interfaceName, quint32 name, quint32 version) {
         if (interfaceName != "zkde_screencast_unstable_v1")
