@@ -18,14 +18,15 @@
 
 int main(int argc, char *argv[])
 {
+    // Do not try to reconnect to the compositor as KWayland can't handle that
+    // Reconsider enabling when we do not use KWayland anymore
+    qunsetenv("QT_WAYLAND_RECONNECT");
     QCoreApplication::setAttribute(Qt::AA_DisableSessionManager);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication a(argc, argv);
     a.setQuitOnLastWindowClosed(false);
+    a.setQuitLockEnabled(false);
 
-    KAboutData about(QStringLiteral("xdg-desktop-portal-kde"), i18n("Portal"), QStringLiteral(XDPK_VERSION_STRING));
+    KAboutData about(QStringLiteral("xdg-desktop-portal-kde"), QString(), QStringLiteral(XDPK_VERSION_STRING));
     about.setDesktopFileName(QStringLiteral("org.freedesktop.impl.portal.desktop.kde"));
     KAboutData::setApplicationData(about);
 
